.. _opening_hours.js: https://github.com/opening-hours/opening_hours.js
.. _git-hours: https://github.com/kimmobrunfeldt/git-hours
.. _Collective: https://en.wikipedia.org/wiki/Collective

.. _ypid: https://me.ypid.de/
.. _htgoebel: https://github.com/htgoebel
